@@ -14,7 +14,7 @@ Version 1.01
 
 =cut
 
-our $VERSION = '1.1';
+our $VERSION = '1.11';
 
 
 =head1 SYNOPSIS
@@ -415,7 +415,7 @@ sub Populate
 			$w_but->pack(@pl, -expand => 1, @$pad2);
 			$cw->{'default_button'} = $w_but  unless(defined($cw->{'default_button'}));
 		}
-		if ($bl eq $escape_button) {
+		if (defined($escape_button) && $bl eq $escape_button) {
 			$cw->{'escape_button'} = $w_but;
 			$cw->bind('<Escape>' => [$w_but => "Invoke"]);
 		}
